@@ -14,7 +14,7 @@ class TFCAdminRuns(TFCEndpoint):
         super().__init__(instance_url, org_name, headers, well_known_paths, verify, log_level)
         self._endpoint_base_url = f"{self._api_v2_base_url}/admin/runs"
 
-    def _required_entitlements(self):
+    def required_entitlements(self):
         return []
 
     def list(self, query=None, filters=None, page=None, page_size=None):
