@@ -14,7 +14,7 @@ class TFCAdminUsers(TFCEndpoint):
         super().__init__(instance_url, org_name, headers, well_known_paths, verify, log_level)
         self._endpoint_base_url = f"{self._api_v2_base_url}/admin/users"
 
-    def _required_entitlements(self):
+    def required_entitlements(self):
         return []
 
     def destroy(self, user_id):
