@@ -3,7 +3,7 @@ Module for Terraform Cloud API Endpoint: Applies.
 """
 
 from .endpoint import TFCEndpoint
-from._constants import Entitlements
+from ._constants import Entitlements
 
 class TFCApplies(TFCEndpoint):
     """
@@ -15,7 +15,7 @@ class TFCApplies(TFCEndpoint):
         super().__init__(instance_url, org_name, headers, well_known_paths, verify, log_level)
         self._endpoint_base_url = f"{self._api_v2_base_url}/applies"
 
-    def _required_entitlements(self):
+    def required_entitlements(self):
         return [Entitlements.OPERATIONS]
 
     def show(self, apply_id):
