@@ -14,7 +14,7 @@ class TFCIPRanges(TFCEndpoint):
         super().__init__(instance_url, org_name, headers, well_known_paths, verify, log_level)
         self._endpoint_base_url = f"{self._meta_base_url}/ip-ranges"
 
-    def _required_entitlements(self):
+    def required_entitlements(self):
         return []
 
     def list(self):
