@@ -3,7 +3,7 @@ Module for Terraform Cloud API Endpoint: OAuth Tokens.
 """
 
 from .endpoint import TFCEndpoint
-from._constants import Entitlements
+from ._constants import Entitlements
 
 class TFCOAuthTokens(TFCEndpoint):
     """
@@ -16,7 +16,7 @@ class TFCOAuthTokens(TFCEndpoint):
         self._oauth_clients_api_v2_base_url = f"{self._api_v2_base_url}/oauth-clients"
         self._oauth_tokens_api_v2_base_url = f"{self._api_v2_base_url}/oauth-tokens"
 
-    def _required_entitlements(self):
+    def required_entitlements(self):
         return [Entitlements.VCS_INTEGRATIONS]
 
     def list(self, oauth_client_id):
