@@ -3,7 +3,7 @@ Module for Terraform Cloud API Endpoint: Policies.
 """
 
 from .endpoint import TFCEndpoint
-from ._constants import Entitlements
+from ._constants import Entitlements, MAX_PAGE_SIZE
 
 class TFCPolicies(TFCEndpoint):
     """
@@ -15,7 +15,7 @@ class TFCPolicies(TFCEndpoint):
         self._endpoint_base_url = f"{self._api_v2_base_url}/policies"
         self._org_api_v2_base_url = f"{self._api_v2_base_url}/organizations/{org_name}/policies"
 
-    def _required_entitlements(self):
+    def required_entitlements(self):
         return [Entitlements.SENTINEL]
 
     def create(self, payload):
@@ -46,6 +46,32 @@ class TFCPolicies(TFCEndpoint):
         return self._list(\
             self._org_api_v2_base_url, page=page, page_size=page_size, search=search)
 
+    def list_all(self, search=None):
+        """
+        This function does not correlate to an endpoint in the TFC API Docs specifically,
+        but rather is a helper function to wrap the `list` endpoint, which enumerates out
+        every page so users do not have to implement the paging logic every time they just
+        want to list every policy for an organization.
+
+        Returns an array of objects.
+        """
+        current_page_number = 1
+        policies_resp = \
+            self._list(self._org_api_v2_base_url, \
+                page=current_page_number, page_size=MAX_PAGE_SIZE, search=search)
+        total_pages = policies_resp["meta"]["pagination"]["total-pages"]
+
+        policies = []
+        while current_page_number <= total_pages:
+            policies_resp = \
+                self._list(\
+                    self._org_api_v2_base_url, \
+                        page=current_page_number, page_size=MAX_PAGE_SIZE, search=search)
+            policies += policies_resp["data"]
+            current_page_number += 1
+
+        return policies
+
     def show(self, policy_id):
         """
         ``GET /policies/:policy_id``
@@ -69,6 +95,19 @@ class TFCPolicies(TFCEndpoint):
         url = f"{self._endpoint_base_url}/{policy_id}"
         return self._update(url, payload)
 
+    def get_policy_text(self, policy_id):
+        """
+        ``GET /policies/:policy_id/download``
+
+        This endpoint is currently not documented in the offical TFC API docs. You can find a
+        reference to it in the `sample response \
+            <https://www.terraform.io/docs/cloud/api/policies.html#sample-response-1>` for the
+        `show` function.
+        """
+        url = f"{self._endpoint_base_url}/{policy_id}/download"
+        byte_results = self._get(url, return_raw=True, allow_redirects=True)
+        return byte_results.decode("utf-8")
+
     def upload(self, policy_id, payload):
         """
         ``PUT /policies/:policy_id/upload``
