@@ -3,7 +3,7 @@ Module for Terraform Cloud API Endpoint: State Version Outputs.
 """
 
 from .endpoint import TFCEndpoint
-from._constants import Entitlements
+from ._constants import Entitlements
 
 class TFCStateVersionOutputs(TFCEndpoint):
     """
@@ -15,7 +15,7 @@ class TFCStateVersionOutputs(TFCEndpoint):
         super().__init__(instance_url, org_name, headers, well_known_paths, verify, log_level)
         self._endpoint_base_url = f"{self._api_v2_base_url}/state-version-outputs"
 
-    def _required_entitlements(self):
+    def required_entitlements(self):
         return [Entitlements.STATE_STORAGE]
 
     def show(self, state_version_output_id):
