@@ -3,7 +3,7 @@ Module for Terraform Cloud API Endpoint: State Versions.
 """
 
 from .endpoint import TFCEndpoint
-from._constants import Entitlements
+from ._constants import Entitlements, MAX_PAGE_SIZE
 
 class TFCStateVersions(TFCEndpoint):
     """
@@ -16,7 +16,7 @@ class TFCStateVersions(TFCEndpoint):
         self._state_version_api_v2_base_url = f"{self._api_v2_base_url}/state-versions"
         self._workspace_api_v2_base_url = f"{self._api_v2_base_url}/workspaces"
 
-    def _required_entitlements(self):
+    def required_entitlements(self):
         return [Entitlements.STATE_STORAGE]
 
     def create(self, workspace_id, payload):
@@ -42,7 +42,7 @@ class TFCStateVersions(TFCEndpoint):
         url = f"{self._workspace_api_v2_base_url}/{workspace_id}/current-state-version"
         return self._get(url)
 
-    def list(self, filters=None, page=None, page_size=None):
+    def list(self, filters, page=None, page_size=None):
         """
         ``GET /state-versions``
 
@@ -74,6 +74,31 @@ class TFCStateVersions(TFCEndpoint):
         url = f"{self._state_version_api_v2_base_url}"
         return self._list(url, filters=filters, page=page, page_size=page_size)
 
+    def list_all(self, filters):
+        """
+        This function does not correlate to an endpoint in the TFC API Docs specifically,
+        but rather is a helper function to wrap the `list` endpoint, which enumerates out
+        every page so users do not have to implement the paging logic every time they just
+        want to list every state version for a workspace.
+
+        Returns an array of objects.
+        """
+        url = self._state_version_api_v2_base_url
+
+        current_page_number = 1
+        state_versions_resp = \
+            self._list(url, filters=filters, page=current_page_number, page_size=MAX_PAGE_SIZE)
+        total_pages = state_versions_resp["meta"]["pagination"]["total-pages"]
+
+        state_versions = []
+        while current_page_number <= total_pages:
+            state_versions_resp = \
+                self._list(url, filters=filters, page=current_page_number, page_size=MAX_PAGE_SIZE)
+            state_versions += state_versions_resp["data"]
+            current_page_number += 1
+
+        return state_versions
+
     def show(self, state_version_id):
         """
         ``GET /state-versions/:state_version_id``
