@@ -15,7 +15,7 @@ class TFCTeamTokens(TFCEndpoint):
         super().__init__(instance_url, org_name, headers, well_known_paths, verify, log_level)
         self._endpoint_base_url = f"{self._api_v2_base_url}/teams"
 
-    def _required_entitlements(self):
+    def required_entitlements(self):
         return [Entitlements.TEAMS]
 
     def create(self, team_id, payload=None):
