@@ -12,6 +12,7 @@ import os
 import binascii
 import time
 import timeout_decorator
+import terrasnek.exceptions
 
 from terrasnek.api import TFC
 from terrasnek._constants import Entitlements
@@ -56,6 +57,10 @@ class TestTFCBaseTestCase(unittest.TestCase):
         cls._test_state_path = "./test/testdata/terraform/terrasnek_unittest.tfstate"
         cls._config_version_upload_tarball_path = \
             "./test/testdata/terraform/terrasnek_unittest_config_version.tar.gz"
+        with open(\
+            './test/testdata/terraform/terrasnek_unittest_config_version_from_string.tf', 'r') \
+                as tf_file:
+            cls._config_version_upload_string = tf_file.read()
         cls._module_upload_tarball_path = \
             "./test/testdata/terraform/terrasnek_unittest_module.tar.gz"
         cls._policy_set_upload_tarball_path = \
@@ -114,7 +119,7 @@ class TestTFCBaseTestCase(unittest.TestCase):
             f"Purging test org ({cls._test_org_name}) of all resources to start fresh...")
 
         cls._logger.info(f"Purging test org ({cls._test_org_name}) of workspaces...")
-        workspaces = cls._api.workspaces.list()["data"]
+        workspaces = cls._api.workspaces.list_all()
         for workspace in workspaces:
             cls._api.workspaces.destroy(workspace_id=workspace["id"])
         cls._logger.debug(f"Workspaces purged from test org ({cls._test_org_name}).")
@@ -125,14 +130,15 @@ class TestTFCBaseTestCase(unittest.TestCase):
             cls._api.registry_modules.destroy(registry_module["name"])
         cls._logger.debug(f"Modules purged from test org ({cls._test_org_name}).")
 
+
         cls._logger.debug(f"Purging test org ({cls._test_org_name}) of policies...")
-        policies = cls._api.policies.list()["data"]
+        policies = cls._api.policies.list_all()
         for policy in policies:
             cls._api.policies.destroy(policy["id"])
         cls._logger.debug(f"Policies purged from test org ({cls._test_org_name}).")
 
         cls._logger.debug(f"Purging test org ({cls._test_org_name}) of policy sets...")
-        policy_sets = cls._api.policy_sets.list()["data"]
+        policy_sets = cls._api.policy_sets.list_all()
         for policy_set in policy_sets:
             cls._api.policy_sets.destroy(policy_set["id"])
         cls._logger.debug(f"Policy sets purged from test org ({cls._test_org_name}).")
@@ -159,14 +165,14 @@ class TestTFCBaseTestCase(unittest.TestCase):
                 cls._api.teams.destroy(team["id"])
         cls._logger.debug(f"Teams purged from test org ({cls._test_org_name}).")
 
-        cls._logger.debug(f"Purging test org ({cls._test_org_name}) of unnecessary org membership invites...")
-        org_memberships = cls._api.org_memberships.list_for_org()["data"]
+        cls._logger.debug(f"Purging test org ({cls._test_org_name}) of org membership invites...")
+        org_memberships = cls._api.org_memberships.list_all_for_org()
         for org_memberships in org_memberships:
             membership_id = org_memberships["id"]
             member_status = org_memberships["attributes"]["status"]
             if member_status == "invited":
                 cls._api.org_memberships.remove(membership_id)
-        cls._logger.debug(f"Unnecessary org member invites purged from test org ({cls._test_org_name}).")
+        cls._logger.debug(f"Org member invites purged from test org ({cls._test_org_name}).")
 
         cls._logger.debug(f"Purging test org ({cls._test_org_name}) of agent pools...")
         agent_pools = cls._api.agents.list_pools()["data"]
@@ -174,14 +180,19 @@ class TestTFCBaseTestCase(unittest.TestCase):
             cls._api.agents.destroy(agent_pool["id"])
         cls._logger.debug(f"Agent pools purged from test org ({cls._test_org_name}).")
 
-        cls._logger.info(f"Test org ({cls._test_org_name}) purged of all resources.")
+        try:
+            cls._logger.debug(f"Purging org token from test org ({cls._test_org_name})...")
+            cls._api.org_tokens.destroy()
+            cls._logger.debug(f"Org token purged from test org ({cls._test_org_name}).")
+        except terrasnek.exceptions.TFCHTTPUnclassified:
+            cls._logger.debug(f"No org token exists for test org ({cls._test_org_name})...")
+
 
-        # TODO: org tokens
 
     @classmethod
     def _get_missing_entitlements(cls, endpoint_attr_name):
         endpoint = getattr(cls._api, endpoint_attr_name)
-        required_entitlements = endpoint._required_entitlements()
+        required_entitlements = endpoint.required_entitlements()
         current_entitlements = cls._api.orgs.entitlements(cls._test_org_name)["data"]["attributes"]
 
         missing_entitlements = []
