@@ -29,9 +29,18 @@ class TestTFCPolicies(TestTFCBaseTestCase):
 
         # List all the policies, search the policy we just created so
         # we can test out the list params
-        all_policies = self._api.policies.list(\
+        some_policies = self._api.policies.list(\
             page=0, page_size=50, search=created_policy_name)["data"]
 
+        found_pol = False
+        for pol in some_policies:
+            if created_policy_id == pol["id"]:
+                found_pol = True
+                break
+        self.assertTrue(found_pol)
+
+        all_policies = self._api.policies.list_all(search=created_policy_name)
+
         found_pol = False
         for pol in all_policies:
             if created_policy_id == pol["id"]:
@@ -47,6 +56,10 @@ class TestTFCPolicies(TestTFCBaseTestCase):
         shown_policy = self._api.policies.show(created_policy_id)["data"]
         shown_policy_id = shown_policy["id"]
 
+        # Get the text of the policy we just created
+        policy_text = self._api.policies.get_policy_text(created_policy_id)
+        self.assertEqual(policy_text, policy_payload)
+
         # Make sure the IDs are the same
         self.assertEqual(shown_policy_id, created_policy_id)
 
@@ -71,5 +84,5 @@ class TestTFCPolicies(TestTFCBaseTestCase):
         self._api.policies.destroy(created_policy_id)
 
         # Check that we now have zero policies again
-        all_policies = self._api.policies.list()["data"]
-        self.assertEqual(len(all_policies), 0)
+        some_policies = self._api.policies.list()["data"]
+        self.assertEqual(len(some_policies), 0)
